#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_tk_api_2', default_args=default_args,
schedule_interval="10 0 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="tk_api_2_failed",
    html_content='<h3>您好，tk_api_2作业失败，请及时处理" </h3>')

customer_events_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_feign',
command='python3 /data/airflow/etl/API/customer_events_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_events_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_feign >> customer_events_load

custom_events_open_page_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_page_feign',
command='python3 /data/airflow/etl/API/custom_events_open_page_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_page_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_page_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_open_page_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_page_feign >> custom_events_open_page_load

custom_events_open_content_page_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_content_page_feign',
command='python3 /data/airflow/etl/API/custom_events_open_content_page_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_content_page_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_content_page_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_open_content_page_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_content_page_feign >> custom_events_open_content_page_load

customer_event_meta_feign = SSHOperator(
ssh_hook=sshHook,
task_id='customer_event_meta_feign',
command='python3 /data/airflow/etl/API/customer_event_meta_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

customer_event_meta_load = SSHOperator(
ssh_hook=sshHook,
task_id='customer_event_meta_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"customer_event_meta_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_event_meta_feign >> customer_event_meta_load

customer_events_open_content_page_9684 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_open_content_page_9684',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_open_content_page"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_event_meta_2268 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_event_meta_2268',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_event_meta"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_open_page_7519 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_open_page_7519',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_open_page"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_3292 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_3292',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events"},
depends_on_past=False, 
retries=3, 
dag=dag)

t01_scrm_leads = SSHOperator(
ssh_hook=sshHook,
task_id='t01_scrm_leads',
command='/data/airflow/etl/PDM/run_sa.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_scrm_leads_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t01_scrm_contact = SSHOperator(
ssh_hook=sshHook,
task_id='t01_scrm_contact',
command='/data/airflow/etl/PDM/run_sa.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_scrm_contact_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
t01_scrm_contact_update = SSHOperator(
ssh_hook=sshHook,
task_id='t01_scrm_contact_update',
command='/data/airflow/etl/PDM/run_sa.sh {{ ds_nodash }} {{params.my_param}} >>/data/airflow/logs/run_tpt_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"t01_scrm_contact_update_agi"},
depends_on_past=False, 
retries=3, 
dag=dag)
customer_events_3292 >> customer_events_feign
customer_events_open_content_page_9684 >> custom_events_open_content_page_feign
customer_event_meta_2268 >> customer_event_meta_feign
customer_events_open_page_7519 >> custom_events_open_page_feign
custom_events_open_content_page_load >> t01_scrm_leads
customer_event_meta_load >> t01_scrm_leads
custom_events_open_page_load >> t01_scrm_leads
t01_scrm_leads >> t01_scrm_contact_update
t01_scrm_leads >> t01_scrm_contact
t01_scrm_contact >> task_failed 
